import { ICols, IColsTypes, IColumnType, IColVar } from './interfaces';
/**
 *
 */
declare class GraphQL {
    /**
     * To resove a column type
     *
     * @param args columns and variables required to resolve
     * @param columnType defition column tyep
     */
    static resolveType(args: IColVar, columnType: IColumnType[], varTypes?: {
        [key: string]: string;
    }): IColsTypes;
    private readonly utilCols;
    private readonly utilVars;
    constructor(columnsType: IColumnType[], varTypes?: {
        [key: string]: string;
    });
    /**
     * To return a query like this one:
     *
     * operation($idLang: String) {
     *  operation {
     *    idTranslation
     *    text(idLang: $idLang) {
     *      idText
     *      idLang
     *    }
     *  }
     * }
     *
     * @param operation required. It's the name of the current operation.
     * @param keys requited. It's the keys to print in the operation brakets.
     * @param variables optional. To print the variables.
     * @param columns optional. To print the columns.
     */
    operation(operation: string, columns: Array<ICols | string>, variables?: string[]): {
        [x: string]: IColsTypes;
    };
    /**
     * This is to resolve the columns to belong to other types
     *
     * @param args required. It can be a array of columns or a object {columns, variabes}
     */
    resolve(args: string[] | IColVar): IColsTypes;
    /**
     * To return a sub-query with params
     *
     *  operation(idLang: $idLang) {
     *    text,
     *    idText,
     *    idLang
     *  }
     *
     * @param operation required. The operation name
     * @param variables required. To print the variables
     * @param columns required. To print the columns.
     */
    private operationVars;
    /**
     * To return a sub-query with operation name and without args
     *
     *  operation {
     *    text,
     *    idText,
     *    idLang
     *  }
     *
     * @param operation required. The operation name
     * @param columns required. To print the columns.
     */
    private operationCols;
    /**
     * To return a sub-query with args
     *
     *  (idLang: $idLang) {
     *    text,
     *    idText,
     *    idLang
     *  }
     *
     * @param variables required. To print the variables
     * @param columns required. To print the columns.
     */
    private vars;
    /**
     *  To return a sub-query columns
     * {
     *  data {
     *    idTranslation: types.number
     *    text {
     *      idText: types.number
     *      idLang: types.string,
     *      text: types.string
     *    }
     *  }
     * }
     *
     * @param columns required. To print the columns.
     */
    private cols;
}
export default GraphQL;
//# sourceMappingURL=GraphQL.d.ts.map