"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const typed_graphqlify_1 = require("typed-graphqlify");
const Util_1 = require("./Util");
/**
 *
 */
class GraphQL {
    constructor(columnsType, varTypes = {}) {
        this.utilCols = new Util_1.Cols(columnsType);
        this.utilVars = new Util_1.Vars(varTypes);
    }
    /**
     * To resove a column type
     *
     * @param args columns and variables required to resolve
     * @param columnType defition column tyep
     */
    static resolveType(args, columnType, varTypes = {}) {
        const graphQL = new GraphQL(columnType, varTypes);
        return graphQL.resolve(args);
    }
    /**
     * To return a query like this one:
     *
     * operation($idLang: String) {
     *  operation {
     *    idTranslation
     *    text(idLang: $idLang) {
     *      idText
     *      idLang
     *    }
     *  }
     * }
     *
     * @param operation required. It's the name of the current operation.
     * @param keys requited. It's the keys to print in the operation brakets.
     * @param variables optional. To print the variables.
     * @param columns optional. To print the columns.
     */
    operation(operation, columns, variables) {
        const operationType = (variables && variables.length > 0) ?
            this.operationVars(operation, variables, columns) :
            this.operationCols(operation, columns);
        const keys = this.utilVars.varsKeys(columns, variables);
        return (keys && Object.keys(keys).length > 0) ? typed_graphqlify_1.params(this.utilVars.varsKeys(columns, variables), operationType) :
            operationType;
    }
    /**
     * This is to resolve the columns to belong to other types
     *
     * @param args required. It can be a array of columns or a object {columns, variabes}
     */
    resolve(args) {
        if (Array.isArray(args)) {
            return this.cols(args);
        }
        return args.variables ?
            this.vars(args.variables, args.columns) :
            this.cols(args.columns);
    }
    /**
     * To return a sub-query with params
     *
     *  operation(idLang: $idLang) {
     *    text,
     *    idText,
     *    idLang
     *  }
     *
     * @param operation required. The operation name
     * @param variables required. To print the variables
     * @param columns required. To print the columns.
     */
    operationVars(operation, variables, columns) {
        return { [operation]: this.vars(variables, columns) };
    }
    /**
     * To return a sub-query with operation name and without args
     *
     *  operation {
     *    text,
     *    idText,
     *    idLang
     *  }
     *
     * @param operation required. The operation name
     * @param columns required. To print the columns.
     */
    operationCols(operation, columns) {
        return { [operation]: this.cols(columns) };
    }
    /**
     * To return a sub-query with args
     *
     *  (idLang: $idLang) {
     *    text,
     *    idText,
     *    idLang
     *  }
     *
     * @param variables required. To print the variables
     * @param columns required. To print the columns.
     */
    vars(variables, columns) {
        return typed_graphqlify_1.params(this.utilVars.varsValues(variables), this.cols(columns));
    }
    /**
     *  To return a sub-query columns
     * {
     *  data {
     *    idTranslation: types.number
     *    text {
     *      idText: types.number
     *      idLang: types.string,
     *      text: types.string
     *    }
     *  }
     * }
     *
     * @param columns required. To print the columns.
     */
    cols(columns) {
        return this.utilCols.cols(columns);
    }
}
exports.default = GraphQL;
//# sourceMappingURL=GraphQL.js.map