"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class Cols {
    constructor(columns) {
        /**
         * Return the columns for the query or mutation
         *
         * {
         *  data {
         *    idTranslation: types.number
         *    text {
         *      idText: types.number
         *      idLang: types.string,
         *      text: types.string
         *    }
         *  }
         * }
         *
         * @param columns
         */
        this.cols = (columnsSelected) => {
            const cols = {};
            for (const col of columnsSelected) {
                if (typeof col === 'string') {
                    const currentCol = this.getCol(col);
                    cols[currentCol.name] = currentCol.resolve;
                }
                else {
                    for (const colName in col) {
                        if (!col.hasOwnProperty(colName)) {
                            continue;
                        }
                        const currentCol = this.getCol(colName);
                        if (typeof currentCol.resolve === 'function') {
                            cols[colName] = currentCol.resolve(col[colName]);
                        }
                        else {
                            throw new Error(`The ${colName} doesn't have a resolve function`);
                        }
                    }
                }
            }
            return cols;
        };
        this.columns = columns;
    }
    /**
     * Return a column
     * @param columnName
     */
    getCol(columnName) {
        for (const column of this.columns) {
            if (column.name === columnName) {
                return column;
            }
        }
        const columnList = this.getNames(this.columns).join(', ');
        throw new Error(`The "${columnName}" doesn't exist in the column list: ${columnList}`);
    }
    /**
     * To get the name of the the columns names
     * @param array
     */
    getNames(array) {
        const columns = [];
        for (const col of array) {
            columns.push(col.name);
        }
        return columns;
    }
}
exports.Cols = Cols;
//# sourceMappingURL=Cols.js.map