"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class Vars {
    constructor(varTypes) {
        /**
         * Return the keys for the query variables, i.e: ($idLang: Int)
         *
         * @param variables the variables of the top query
         * @param columnsSelected the variables of the childs
         */
        this.varsKeys = (columnsSelected, variables) => {
            let varsArray = this.getVariableNames(columnsSelected);
            if (variables && variables.length > 0) {
                varsArray = Array.from(new Set([...varsArray, ...variables]));
            }
            const vars = {};
            for (const varName of varsArray) {
                const type = this.varTypes[varName];
                if (typeof type === 'undefined') {
                    throw this.Error(varName);
                }
                const keyName = '$' + varName;
                vars[keyName] = type;
            }
            return vars;
        };
        /**
         * Return the values for the query variable function, i.e: (idLang: $idLang)
         */
        this.varsValues = (variables) => {
            const vars = {};
            for (const varName of variables) {
                const type = this.varTypes[varName];
                if (typeof type === 'undefined') {
                    throw this.Error(varName);
                }
                vars[varName] = '$' + varName;
            }
            return vars;
        };
        this.getVariableNames = (columns) => {
            const vars = [];
            for (const column of columns) {
                if (typeof column === 'object') {
                    for (const key in column) {
                        if (Array.isArray(column[key])) {
                            const curentCol = column[key];
                            const varx = this.getVariableNames(curentCol);
                            if (varx.length > 0) {
                                vars.push(...varx);
                            }
                        }
                        else if ('variables' in column[key]) {
                            const curentCol = column[key];
                            if (curentCol.variables) {
                                vars.push(...curentCol.variables);
                            }
                            if (Array.isArray(curentCol.columns)) {
                                const varx = this.getVariableNames(curentCol.columns);
                                if (varx.length > 0) {
                                    vars.push(...varx);
                                }
                            }
                        }
                    }
                }
            }
            return vars;
        };
        this.varTypes = varTypes;
    }
    Error(varName) {
        const typesList = Object.keys(this.varTypes).join(', ');
        return new Error(`The "${varName}" doesn't exist in the types list: ${typesList}`);
    }
}
exports.Vars = Vars;
//# sourceMappingURL=Vars.js.map