"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const __1 = require("../../");
const queries_1 = require("../queries");
const types_1 = require("../types");
describe('GraphQL-Type-Query', () => {
    it('render GraphQL - basic', () => {
        const columns = [
            'idLang',
            'name',
            'localName',
        ];
        const queryString = queries_1.langsQuery.toString({ columns });
        expect(queryString).toEqual('query langs{langs{idLang name localName}}');
    });
    it('render GraphQL - variable', () => {
        const query = new __1.Query('user', types_1.userType, { idUser: 'Int' });
        const columns = [
            'idUser',
            'name',
            'email',
        ];
        const queryString = query.toString({ columns, variables: ['idUser'] });
        expect(queryString).toEqual('query user($idUser:Int){user(idUser:$idUser){idUser name email}}');
    });
    it('render GraphQL - variable  in subqueries', () => {
        const columns = [
            'idTranslation',
            {
                text: {
                    columns: ['idText', 'text'],
                    variables: ['idLang'],
                },
            },
        ];
        const queryString = queries_1.translationQuery.toString({
            columns,
            variables: ['idTranslation'],
        });
        expect(queryString).toEqual('query translation($idLang:String,$idTranslation:Int){translation(idTranslation:$idTranslation){idTranslation text(idLang:$idLang){idText text}}}');
    });
    it('properly errors on invalid input', () => {
        const query = new __1.Query('user', [{
                name: 'idUser',
                resolve: __1.types.number,
            }]);
        expect(() => query.toString({ columns: ['idUser'], variables: ['noVariable'] })).toThrow();
        expect(() => query.toString({ columns: ['NoColumn'] })).toThrow();
    });
});
//# sourceMappingURL=Query.js.map